flushInstance static method

  1. @Deprecated("This features is no longer required for Dart hook implementation.")
void flushInstance()

Flush existed SuperuserInterface instance.

Implementation

@Deprecated(
  "This features is no longer required for Dart hook implementation.",
)
static void flushInstance() {
  if (_instance != null) {
    _instance = null;
  }
}