mock library
Replicate SuperuserInterface to emulate superuser condition in controllable values when performing debugs or testing.
Classes
- MockSuperuser
- Replicate behaviour of SuperuserInterface, which fulfilled requirements of testing.
- OSString
- Replicated String with modified matching mechnism applied depended on which OS is used. OSString will print unmodified string from input when calling toString.
- OSStringsSet
- A collection of OSString with every elements comply matching staregy when the first OSString inserted.